==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkXdmf3Reader.java <==
// java wrapper for vtkXdmf3Reader object
//

package vtk;
import vtk.*;

public class vtkXdmf3Reader extends vtkDataReader
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFileName_2(String id0);
  public void SetFileName(String id0)
    { SetFileName_2(id0); }

  private native void AddFileName_3(String id0);
  public void AddFileName(String id0)
    { AddFileName_3(id0); }

  private native void RemoveAllFileNames_4();
  public void RemoveAllFileNames()
    { RemoveAllFileNames_4(); }

  private native void SetFileSeriesAsTime_5(boolean id0);
  public void SetFileSeriesAsTime(boolean id0)
    { SetFileSeriesAsTime_5(id0); }

  private native boolean GetFileSeriesAsTime_6();
  public boolean GetFileSeriesAsTime()
    { return GetFileSeriesAsTime_6(); }

  private native int CanReadFile_7(String id0);
  public int CanReadFile(String id0)
    { return CanReadFile_7(id0); }

  private native int GetNumberOfPointArrays_8();
  public int GetNumberOfPointArrays()
    { return GetNumberOfPointArrays_8(); }

  private native String GetPointArrayName_9(int id0);
  public String GetPointArrayName(int id0)
    { return GetPointArrayName_9(id0); }

  private native int GetPointArrayStatus_10(String id0);
  public int GetPointArrayStatus(String id0)
    { return GetPointArrayStatus_10(id0); }

  private native void SetPointArrayStatus_11(String id0,int id1);
  public void SetPointArrayStatus(String id0,int id1)
    { SetPointArrayStatus_11(id0,id1); }

  private native int GetNumberOfCellArrays_12();
  public int GetNumberOfCellArrays()
    { return GetNumberOfCellArrays_12(); }

  private native String GetCellArrayName_13(int id0);
  public String GetCellArrayName(int id0)
    { return GetCellArrayName_13(id0); }

  private native void SetCellArrayStatus_14(String id0,int id1);
  public void SetCellArrayStatus(String id0,int id1)
    { SetCellArrayStatus_14(id0,id1); }

  private native int GetCellArrayStatus_15(String id0);
  public int GetCellArrayStatus(String id0)
    { return GetCellArrayStatus_15(id0); }

  private native int GetNumberOfFieldArrays_16();
  public int GetNumberOfFieldArrays()
    { return GetNumberOfFieldArrays_16(); }

  private native String GetFieldArrayName_17(int id0);
  public String GetFieldArrayName(int id0)
    { return GetFieldArrayName_17(id0); }

  private native void SetFieldArrayStatus_18(String id0,int id1);
  public void SetFieldArrayStatus(String id0,int id1)
    { SetFieldArrayStatus_18(id0,id1); }

  private native int GetFieldArrayStatus_19(String id0);
  public int GetFieldArrayStatus(String id0)
    { return GetFieldArrayStatus_19(id0); }

  private native int GetNumberOfGrids_20();
  public int GetNumberOfGrids()
    { return GetNumberOfGrids_20(); }

  private native String GetGridName_21(int id0);
  public String GetGridName(int id0)
    { return GetGridName_21(id0); }

  private native void SetGridStatus_22(String id0,int id1);
  public void SetGridStatus(String id0,int id1)
    { SetGridStatus_22(id0,id1); }

  private native int GetGridStatus_23(String id0);
  public int GetGridStatus(String id0)
    { return GetGridStatus_23(id0); }

  private native int GetNumberOfSets_24();
  public int GetNumberOfSets()
    { return GetNumberOfSets_24(); }

  private native String GetSetName_25(int id0);
  public String GetSetName(int id0)
    { return GetSetName_25(id0); }

  private native void SetSetStatus_26(String id0,int id1);
  public void SetSetStatus(String id0,int id1)
    { SetSetStatus_26(id0,id1); }

  private native int GetSetStatus_27(String id0);
  public int GetSetStatus(String id0)
    { return GetSetStatus_27(id0); }

  private native int GetNumberOfSetArrays_28();
  public int GetNumberOfSetArrays()
    { return GetNumberOfSetArrays_28(); }

  private native String GetSetArrayName_29(int id0);
  public String GetSetArrayName(int id0)
    { return GetSetArrayName_29(id0); }

  private native int GetSetArrayStatus_30(String id0);
  public int GetSetArrayStatus(String id0)
    { return GetSetArrayStatus_30(id0); }

  private native long GetSIL_31();
  public vtkGraph GetSIL() {
    long temp = GetSIL_31();

    if (temp == 0) return null;
    return (vtkGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int GetSILUpdateStamp_32();
  public int GetSILUpdateStamp()
    { return GetSILUpdateStamp_32(); }

  public vtkXdmf3Reader() { super(); }

  public vtkXdmf3Reader(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-18-aarch64.pkg.tar.xz: vtk/vtkXdmf3Reader.java <==
// java wrapper for vtkXdmf3Reader object
//

package vtk;
import vtk.*;

public class vtkXdmf3Reader extends vtkDataObjectAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFileName_2(String id0);
  public void SetFileName(String id0)
    { SetFileName_2(id0); }

  private native void AddFileName_3(String id0);
  public void AddFileName(String id0)
    { AddFileName_3(id0); }

  private native void RemoveAllFileNames_4();
  public void RemoveAllFileNames()
    { RemoveAllFileNames_4(); }

  private native void SetFileSeriesAsTime_5(boolean id0);
  public void SetFileSeriesAsTime(boolean id0)
    { SetFileSeriesAsTime_5(id0); }

  private native boolean GetFileSeriesAsTime_6();
  public boolean GetFileSeriesAsTime()
    { return GetFileSeriesAsTime_6(); }

  private native int CanReadFile_7(String id0);
  public int CanReadFile(String id0)
    { return CanReadFile_7(id0); }

  private native int GetNumberOfPointArrays_8();
  public int GetNumberOfPointArrays()
    { return GetNumberOfPointArrays_8(); }

  private native String GetPointArrayName_9(int id0);
  public String GetPointArrayName(int id0)
    { return GetPointArrayName_9(id0); }

  private native int GetPointArrayStatus_10(String id0);
  public int GetPointArrayStatus(String id0)
    { return GetPointArrayStatus_10(id0); }

  private native void SetPointArrayStatus_11(String id0,int id1);
  public void SetPointArrayStatus(String id0,int id1)
    { SetPointArrayStatus_11(id0,id1); }

  private native int GetNumberOfCellArrays_12();
  public int GetNumberOfCellArrays()
    { return GetNumberOfCellArrays_12(); }

  private native String GetCellArrayName_13(int id0);
  public String GetCellArrayName(int id0)
    { return GetCellArrayName_13(id0); }

  private native void SetCellArrayStatus_14(String id0,int id1);
  public void SetCellArrayStatus(String id0,int id1)
    { SetCellArrayStatus_14(id0,id1); }

  private native int GetCellArrayStatus_15(String id0);
  public int GetCellArrayStatus(String id0)
    { return GetCellArrayStatus_15(id0); }

  private native int GetNumberOfFieldArrays_16();
  public int GetNumberOfFieldArrays()
    { return GetNumberOfFieldArrays_16(); }

  private native String GetFieldArrayName_17(int id0);
  public String GetFieldArrayName(int id0)
    { return GetFieldArrayName_17(id0); }

  private native void SetFieldArrayStatus_18(String id0,int id1);
  public void SetFieldArrayStatus(String id0,int id1)
    { SetFieldArrayStatus_18(id0,id1); }

  private native int GetFieldArrayStatus_19(String id0);
  public int GetFieldArrayStatus(String id0)
    { return GetFieldArrayStatus_19(id0); }

  private native int GetNumberOfGrids_20();
  public int GetNumberOfGrids()
    { return GetNumberOfGrids_20(); }

  private native String GetGridName_21(int id0);
  public String GetGridName(int id0)
    { return GetGridName_21(id0); }

  private native void SetGridStatus_22(String id0,int id1);
  public void SetGridStatus(String id0,int id1)
    { SetGridStatus_22(id0,id1); }

  private native int GetGridStatus_23(String id0);
  public int GetGridStatus(String id0)
    { return GetGridStatus_23(id0); }

  private native int GetNumberOfSets_24();
  public int GetNumberOfSets()
    { return GetNumberOfSets_24(); }

  private native String GetSetName_25(int id0);
  public String GetSetName(int id0)
    { return GetSetName_25(id0); }

  private native void SetSetStatus_26(String id0,int id1);
  public void SetSetStatus(String id0,int id1)
    { SetSetStatus_26(id0,id1); }

  private native int GetSetStatus_27(String id0);
  public int GetSetStatus(String id0)
    { return GetSetStatus_27(id0); }

  private native int GetNumberOfSetArrays_28();
  public int GetNumberOfSetArrays()
    { return GetNumberOfSetArrays_28(); }

  private native String GetSetArrayName_29(int id0);
  public String GetSetArrayName(int id0)
    { return GetSetArrayName_29(id0); }

  private native int GetSetArrayStatus_30(String id0);
  public int GetSetArrayStatus(String id0)
    { return GetSetArrayStatus_30(id0); }

  private native long GetSIL_31();
  public vtkGraph GetSIL() {
    long temp = GetSIL_31();

    if (temp == 0) return null;
    return (vtkGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetSILUpdateStamp_32();
  public int GetSILUpdateStamp()
    { return GetSILUpdateStamp_32(); }

  public vtkXdmf3Reader() { super(); }

  public vtkXdmf3Reader(long id) { super(id); }
  public native long   VTKInit();

}
